OpenConnectionArguments

Struct OpenConnectionArguments 

pub struct OpenConnectionArguments { /* private fields */ }
The arguments used by Connection::open.

Methods can be chained in order to build the desired argument values, call finish to finish chaining and returns a new argument.

Chaining configuration implies an additional clone when finish is called.

Examples:

Chaining configuration style


// Create a default and update only `credentials` field, then return desired config.
let args = OpenConnectionArguments::default()
    .credentials(SecurityCredentials::new_amqplain("user", "bitnami"))
    .finish();

// Create a new one and update the fields, then return desired config
let args = OpenConnectionArguments::new("localhost", 5672, "user", "bitnami")
    .virtual_host("myhost")
    .connection_name("myconnection")
    .finish();

Non-chaining configuration style


// create a new and mutable argument
let mut args = OpenConnectionArguments::new("localhost", 5672, "user", "bitnami");
// update fields of the mutable argument
args.virtual_host("myhost").connection_name("myconnection");

Create from URI string if feature “urispec” is enabled

let args: OpenConnectionArguments = "amqp://user:bitnami@localhost".try_into().unwrap();

Implementations

Source

impl OpenConnectionArguments

pub fn new(host: &str, port: u16, username: &str, password: &str) -> Self

Return a new argument with default configuration.

Default

Use virtual host “/”, SASL/PLAIN authentication and auto generated connection name.

pub fn host(&mut self, host: &str) -> &mut Self

Set the host of the server.

Default

“localhost”

pub fn get_host(&self) -> &str

Get the host of the server.

pub fn port(&mut self, port: u16) -> &mut Self

Set the port of the server.

Default

5672 by AMQP 0-9-1 spec.

pub fn get_port(&self) -> u16

Get the port of the server.

pub fn virtual_host(&mut self, virtual_host: &str) -> &mut Self

Set the virtual host. See RabbitMQ vhosts.

Default

“/”

pub fn get_virtual_host(&self) -> &str

Get the virtual host of the server.

pub fn connection_name(&mut self, connection_name: &str) -> &mut Self

Set the connection name.

Default

Name is auto generated.

pub fn get_connection_name(&self) -> Option<&str>

Get the connection name.

pub fn credentials(&mut self, credentials: SecurityCredentials) -> &mut Self

Set the user credentials. See RabbitMQ access control.

Default

SASL/PLAIN authentication, “guest” as both username and password.

pub fn get_credentials(&self) -> &SecurityCredentials

Get the credentials.

pub fn heartbeat(&mut self, heartbeat: u16) -> &mut Self

Set the heartbeat timeout in seconds. See RabbitMQ heartbeats.

Default

60 seconds.

pub fn get_heartbeat(&self) -> u16

Get the heartbeat.

pub fn scheme(&mut self, scheme: &str) -> &mut Self

Set the URI scheme.

pub fn get_scheme(&self) -> Option<&str>

Get the connection scheme.

pub fn tls_adaptor(&mut self, tls_adaptor: TlsAdaptor) -> &mut Self

Set SSL/TLS adaptor. Set to enable SSL/TLS connection.

Default

No SSL/TLS enabled

pub fn get_tls_adaptor(&self) -> Option<&TlsAdaptor>

Get the TLS adaptor.

pub fn finish(&mut self) -> Self

Finish chaining and returns a new argument according to chained configurations.

It actually clones the resulted configurations.